import { defineComponent, $prefix, props, setup, h } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/pull-refresh-mobile-first/vue';
import Loading from '@opentinyvue/vue-loading';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
var __vue2_script = defineComponent({
  name: $prefix + "PullRefresh",
  emits: ["change", "refresh", "update:modelValue"],
  props: [].concat(props, ["disabled", "modelValue", "headHeight", "successText", "pullingText", "loosingText", "loadingText", "pullDistance", "successDuration", "animationDuration", "loadingOptions", "selfSimulate"]),
  setup: function setup$1(props2, context) {
    var apis = setup({
      props: props2,
      context,
      renderless,
      api,
      extendOptions: {
        Loading
      }
    });
    var state = apis.state, getStatusText = apis.getStatusText, constants = apis.constants;
    var _constants$STATUS = constants.STATUS, PULLING = _constants$STATUS.PULLING, LOOSING = _constants$STATUS.LOOSING, SUCCESS = _constants$STATUS.SUCCESS;
    var HeadComponent = {
      render: function render3() {
        var slots = context.slots;
        var status = state.status, distance = state.distance;
        var children;
        if (slots[status]) {
          children = [slots[status]({
            distance
          })];
        } else {
          children = [];
          if ([PULLING, LOOSING, SUCCESS].includes(status)) {
            children.push(h("div", {
              attrs: {
                "data-tag": "tiny-pull-refresh__text"
              }
            }, [getStatusText()]));
          }
        }
        return h("div", {
          class: ["absolute left-0 -translate-y-full overflow-hidden text-base text-color-text-info-primary text-center", "w-full h-[var(--tiny-pull-refresh-head-height)] leading-[var(--tiny-pull-refresh-head-height)]"],
          attrs: {
            "data-tag": "tiny-pull-refresh__head"
          }
        }, children);
      }
    };
    return _extends({}, apis, {
      HeadComponent
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    ref: "root",
    style: {
      "--tiny-pull-refresh-head-height": _vm.state.headerHeight
    },
    attrs: {
      "data-tag": "tiny-pull-refresh"
    }
  }, [_c("div", {
    ref: "track",
    staticClass: "relative h-fit transition-transform",
    style: {
      transitionDuration: _vm.state.duration + "ms",
      transform: _vm.state.distance ? "translate3d(0," + _vm.state.distance + "px, 0)" : ""
    },
    attrs: {
      "data-tag": "tiny-pull-refresh__track",
      "data-tiny-touch-simulate-container": ""
    },
    on: {
      "&touchstart": function touchstart($event) {
        return _vm.onTouchStart.apply(null, arguments);
      },
      "touchend": _vm.onTouchEnd,
      "touchcancel": _vm.onTouchEnd
    }
  }, [_c(_vm.HeadComponent, {
    ref: "head",
    tag: "component"
  }), _vm._t("default")], 2)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
